Enum Msibias
#[repr(u8)]pub enum Msibias {
Continuous = 0,
Sampling = 1,
}Variants
Continuous = 0
MSI bias continuous mode (clock accuracy fast settling time).
Sampling = 1
MSI bias sampling mode when the device is in Stop 1 or Stop 2 mode, or when the regulator is in range 2.
Implementations